[![Build Status](https://dev.azure.com/moroen/PyCOAP/_apis/build/status/pycoap?branchName=master)](https://dev.azure.com/moroen/PyCOAP/_build/latest?definitionId=1&branchName=master)

# PyCOAP

A python extension module written in GOLANG to provide basic COAP-capabilities, including support for DTLS.


## Requirements
To  compile and install PyCOAP you need:

### golang-compiler and python developement packages

```shell
  $ sudo apt install golang python3 python3-dev
```

### Updated pip and setuptools

```shell
  $ sudo pip3 install -U pip setuptools
```

## Installation

```shell
  $ git clone https://github.com/moroen/pycoap.git
  $ cd pycoap
  $ sudo python3 setup.py install
```

## Usage
See included pycoap-client for a small example
